@@ -40,3 +40,13 @@ class HDF5Generator:
         d_set = d_set.shuffle(n_shuffle, reshuffle_each_iteration=True) if shuffle else d_set
 
         return d_set.batch(batch_size).prefetch(tf.data.experimental.AUTOTUNE).repeat()
+
+    def nan_check(self):
+        key = "{}_data".format(self.prefix)
+
+        is_nan = False
+        for i in range(self.data[key].shape[0]):
+            if np.sum(np.isnan(self.data[key][i].flatten())) > 0:
+                print("NaN Exist! on {}".format(i))
+                is_nan = True
+        return is_nan
