@@ -2,6 +2,7 @@ import h5py
 import numpy as np
 from .preprocess import generate_sliding_window_data
 from .preprocess import reshape_data
+from tqdm import tqdm
 
 
 def append_h5py_data(data, fname, db_key, dtype='float32'):
@@ -38,17 +39,20 @@ def save_windowed_data_hdf5(data, label, s_idx=-1, e_idx=-1, window_size=300, st
 def save_windowed_dataset_hdf5(training_data, training_label, test_data, test_label,
                                window_size=300, stride=1, save_root='../data/',
                                chunk_size=100):
-    for i in range(0, len(training_data), chunk_size):
+    for i in tqdm(range(0, len(training_data), chunk_size), desc="Generating sliding window (training) ..."):
         s_idx = i
         e_idx = min(i + chunk_size, len(training_data))
         save_windowed_data_hdf5(training_data, training_label, s_idx, e_idx, window_size=window_size,
-                                stride=stride, save_root="{}".format(save_root), prefix="training")
+                                stride=stride, save_root="{}".format(save_root), prefix="training",
+                                verbose=0)
 
-    for i in range(0, len(test_data), chunk_size):
+    for i in tqdm(range(0, len(test_data), chunk_size), desc="Generating sliding window (test) ..."):
         s_idx = i
         e_idx = min(i + chunk_size, len(test_data))
         save_windowed_data_hdf5(test_data, test_label, s_idx, e_idx, window_size=window_size,
-                                stride=stride, save_root="{}".format(save_root), prefix="test")
+                                stride=stride, save_root="{}".format(save_root), prefix="test",
+                                verbose=0)
+
 
 if __name__ == "__main__":
     pass
