@@ -1,22 +1,21 @@
 import numpy as np
 
 
-def normalize_data(data, norm_max=1):
-    min_v = np.ones(data[0].shape[1:]) * np.inf
-    max_v = np.ones(data[0].shape[1:]) * -np.inf
+def normalize_data(data):
+    concat_data = np.concatenate([np.swapaxes(d, 1, 2).reshape(-1, d.shape[1]) for d in data])
+    concat_data = np.split(concat_data, concat_data.shape[1] // 3, axis=1)
+
+    std_v = [c_data.std() for c_data in concat_data]
+    mean_v = [m_data.mean() for m_data in concat_data]
 
     for d in data:
-        for i in range(d.shape[1]):
-            for j in range(d.shape[2]):
-                min_v[i, j] = min(min_v[i, j], d[:, i, j].min())
-                max_v[i, j] = max(max_v[i, j], d[:, i, j].max())
+        for i in range(d.shape[1]//3):
+            s_idx = i * 3
+            e_idx = i * 3 + 3
 
-    for d in data:
-        for i in range(d.shape[1]):
-            for j in range(d.shape[2]):
-                d[:, i, j] = ((d[:, i, j] - min_v[i, j]) / (max_v[i, j]-min_v[i, j])) * norm_max
+            d[:, s_idx:e_idx, :] = (d[:, s_idx:e_idx, :] - mean_v[i]) / std_v[i]
 
-    return data
+    return data, std_v, mean_v
 
 
 def reshape_data(data, rotate=True):
